@@ -22,7 +22,7 @@ require Exporter;
 @EXPORT = qw(
         
 );
-$VERSION = '0.07';
+$VERSION = '0.08';
 
 use constant REV_BEGINNING => 2375840; # 1 Vendémiaire I in the Revolutionary calendar
 my @MONTHS_SHORT  = qw ( Vnd Bru Fri Niv Plu Vnt Ger Flo Pra Mes The Fru S-C);
@@ -175,6 +175,8 @@ my @YEARS_BEGINS=    (0, 365, 730, 1096, 1461, 1826, 2191, 2557, 2922, 3287, 365
 
 # This method shoudl be in the master class, but for the moment, it is only available here
 sub change_to {
+  croak "Need to specify the new calendar"
+    if @_ <= 1;
   my ($self, $new_cal) = @_;
   $new_cal->convert($self);
 }
@@ -412,6 +414,7 @@ Converting from Revolutionary to Gregorian (or other)
 
     $date = Date::Convert::French_Rev->new(8, 2, 18);   # 18 Brumaire VIII...
     Date::Convert::Gregorian->convert($date);
+    print $date->date_string, "\n";                     # ... is "1799 Nov 9"
 
 Alternate way of converting from Revolutionary to Gregorian (or other)
 
@@ -470,7 +473,16 @@ Boolean.
 
 =item convert
 
-Change the date to a new format.
+Change the date to a new format. The invocant is the class name of the
+destination calendar, the parameter is the C<Date::Convert::>I<whatever>
+object to convert.
+
+=item change_to
+
+Change the date to a new format. The invocant is the
+C<Date::Convert::>I<whatever> object to convert, the parameter is the
+class name of the destination calendar. For the moment, this method is
+available only for C<Date::Convert::French_Rev> invocant objects.
 
 =item date_string
 
@@ -743,7 +755,6 @@ General Public License for more details.
 
 You  should have received  a copy  of the  GNU General  Public License
 along  with  this  program;  if   not,  write  to  the  Free  Software
-Foundation, Inc.,  59 Temple Place, Suite 330,  Boston, MA 02111-1307,
-USA.
+Foundation, Inc., <http://www.fsf.org/>.
 
 =cut
